import { Source } from "./Source";
export interface Plugin {
    name: string;
    type: PluginType;
    sourceTypes: string[];
    fn: ExtractorPlugin | MutationPlugin;
}
export declare enum PluginType {
    EXTRACTOR = "extractor",
    MUTATION = "mutation"
}
export declare type PluginOptions<T = Record<string, any>> = T;
export interface PluginWithOptions<T = Record<string, any>> {
    plugin: Plugin;
    options: PluginOptions<T>;
}
export interface ExtractorPluginReturnType {
    [key: string]: any;
}
export interface ExtractorPluginArgs<T = Record<string, any>, C = string> {
    source: Source<C>;
    options?: PluginOptions<T>;
}
export declare type ExtractorPlugin = (args: ExtractorPluginArgs) => ExtractorPluginReturnType;
export declare type MutationPluginReturnType = string | any;
export interface MutationPluginArgs<T = Record<string, any>, C = string> {
    source: Source<C>;
    options?: PluginOptions<T>;
}
export declare type MutationPlugin = (args: MutationPluginArgs) => MutationPluginReturnType;
export declare type PluginT = Plugin | PluginWithOptions;
export declare type Plugins = PluginT[];
export declare function isPlugin(plugin: PluginT): plugin is Plugin;
export declare function isPluginWithOptions(plugin: PluginT): plugin is PluginWithOptions;
