import { PluginOptions } from "./Plugin";
import { RenderEngineOptions } from "./RenderEngine";
export interface PluginOptionsForSource<T = any> {
    name: string;
    options: PluginOptions;
}
export interface RenderEngineOptionsForSource<T = any> {
    name: string;
    options: RenderEngineOptions;
}
export interface Source<C = string> {
    type: string;
    rawContent: C;
    content?: C;
    data?: Record<string, any>;
}
export interface SourceWithOptions<C = string> {
    source: Source<C>;
    pluginsOptions?: PluginOptionsForSource[];
    renderEngineOptions?: RenderEngineOptionsForSource[];
}
export interface SourceGroupWithOptions<C = string> {
    sources: Array<SourceWithOptions<C>>;
    pluginsOptions?: PluginOptionsForSource[];
    renderEngineOptions?: RenderEngineOptionsForSource[];
}
export declare type SourceType<C = string> = SourceWithOptions<C> | SourceGroupWithOptions<C>;
export declare type Sources<C = string> = Array<SourceType<C>>;
export declare function isSourceWithOptions(source: SourceType): source is SourceWithOptions;
export declare function isSourceGroupWithOptions(source: SourceType): source is SourceGroupWithOptions;
export declare type PureSourceType<C = string> = Source<C> | Array<Source<C>>;
export declare type PureSources<C = string> = Array<PureSourceType<C>>;
export declare function isSource(source: PureSourceType): source is Source;
export declare function isSourceArray(source: PureSourceType): source is Source[];
